#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NEGS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NEGS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/negs.hpp>

#endif
